@@ -1,9 +1,8 @@
-from base import Base
+from read import Read
 
-class Resolve(Base):
+class Resolve(Read):
     def __init__(self, api, values={}):
-        self.path = 'places/resolve'
-        Base.__init__(self, api, {'values': values})
+        Read.__init__(self, api, 'places/resolve', values)
 
     def values(self, values):
         return self._copy({'values': values})
@@ -12,4 +11,4 @@ class Resolve(Base):
         return self._copy({'include_count': include})
 
     def _copy(self, params):
-        return Resolve(self.api, self.path, self.merge_params(params))
+        return Resolve(self.api, self.merge_params(params))
